@@ -25,7 +25,7 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
   ##              If given as a vector, CV[1] /must/ be the CV of T and
   ##              CV[2] the CV of R. Important!
   ##   design     "2x2x4", "2x2x3", "2x3x3". Defaults to "2x3x3".
-  ##   regulator  "EMA" or "HC". ANVISA recently adopted EMA's rules.
+  ##   regulator  "EMA", "HC", "FDA".
   ##   n          Total sample size or a vector of subjects/sequences.
   ##   nsims      Simulations for the TIE. Should not be <1E6.
   ##   imax       Max. steps in sample size search.
@@ -57,11 +57,11 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
   ##   Assessment of TIE; alpha.pre is justified if not > alpha.
   ################################################################
   ## Tested on Win 7 Pro SP1 64bit                              ##
-  ##   R 3.3.3 64bit (2017-03-06), PowerTOST 1.4-4 (2017-03-15) ##
+  ##   R 3.4.2 64bit (2017-09-28), PowerTOST 1.4-6 (2017-08-17) ##
   ################################################################
   env <- as.character(Sys.info()[1]) # get info about the OS
   ifelse ((env == "Windows") || (env == "Darwin"), flushable <- TRUE,
-    flushable <- FALSE) # supress flushing on other OS's
+          flushable <- FALSE) # supress flushing on other OS's
   # acceptance range defaults
   if (missing(theta1) && missing(theta2)) theta1 <- 0.8
   if (missing(theta2)) theta2 = 1/theta1
@@ -71,10 +71,9 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
     stop("theta0 must be within [theta1, theta2]")
   # check regulator arg
   if(missing(regulator)) regulator <- "EMA"
-  # should we also allow "FDA"?
-  reg <- reg_check(regulator, choices=c("EMA", "HC"))
-  if (regulator == "HC" && sdsims)
-    stop("Subject data simulations are not supported for regulator='HC'.")
+  reg <- reg_check(regulator, choices=c("EMA", "HC", "FDA"))
+  if (regulator %in% c("HC", "FDA") && sdsims)
+    stop("Subject data simulations are not supported for regulator=\'HC\' or \'FDA\'.")
   # set iteration tolerance for uniroot().
   if (missing(tol)) tol <- 1e-6
   design <- match.arg(design)
@@ -91,14 +90,22 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
       al <- alpha    # If not, use alpha (commonly 0.05)
     }
     # sample size for targetpower 0.8
-    n <- sampleN.scABEL(alpha = al, CV = CV, theta0 = theta0,
-                        theta1 = theta1, theta2 = theta2,
-                        design = design, regulator = reg,
-                        imax = imax, print = FALSE, details = FALSE,
-                        setseed = setseed)[["Sample size"]]
+    if (!reg$name == "FDA") { # EMA or HC
+      n <- sampleN.scABEL(alpha = al, CV = CV, theta0 = theta0,
+                          theta1 = theta1, theta2 = theta2,
+                          design = design, regulator = reg,
+                          imax = imax, print = FALSE, details = FALSE,
+                          setseed = setseed)[["Sample size"]]
+    } else {                 # FDA
+      n <- sampleN.RSABE(alpha = al, CV = CV, theta0 = theta0,
+                         theta1 = theta1, theta2 = theta2,
+                         design = design, regulator = reg,
+                         imax = imax, print = FALSE, details = FALSE,
+                         setseed = setseed)[["Sample size"]]
+    }
     if (is.na(n))
-      stop(paste0("Sample size search in sampleN.scABEL() failed.\n",
-                  "Restart with an explicit high n (>1000)."))
+      stop(paste0("Sample size search in sampleN.scABEL() or sampleN.RSABE() failed.\n",
+                  "Restart with an explicitly high n (>1000)."))
     no <- 1e5
   }
   if (sum(n) < 6) stop("Sample size too low.")
@@ -109,15 +116,23 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
   }
   seqs <- as.numeric(substr(design, 3, 3)) # subjects / sequence
   if (length(n) == 1) n <- nvec(n, seqs)   # vectorize n
-
+  
   # here we go!
   TIE <- pwr <- rep(NA, 2) # initialize vectors: TIE and pwr
   alpha.adj <- NA          # adjusted alpha
   # Finds adjusted alpha which gives TIE as close as possible to alpha.
   # Simulate underlying statistics (if sdsims=FALSE)
-  opt1 <- function(x) power.scABEL(alpha = x, CV = CV, theta0 = U, n = n,
-                                   regulator = reg, design = design,
-                                   nsims = nsims, setseed = setseed) - alpha
+  opt1 <- function(x) {
+    if (!reg$name == "FDA") { # EMA or HC
+      power.scABEL(alpha = x, CV = CV, theta0 = U, n = n,
+                   regulator = reg, design = design,
+                   nsims = nsims, setseed = setseed) - alpha
+    } else {                  # FDA
+      power.RSABE(alpha = x, CV = CV, theta0 = U, n = n,
+                  regulator = reg, design = design,
+                  nsims = nsims, setseed = setseed) - alpha
+    }
+  }
   # Simulate subject data (if sdsims=TRUE)
   opt2 <- function(x) power.scABEL.sdsims(alpha = x, CV = CV, theta0 = U,
                                           n = n, regulator = reg,
@@ -128,11 +143,14 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
                     alternative = "less",
                     conf.level = 1 - alpha)$conf.int[2]
   method <- "ABE"
-  if (CVwR > reg$CVswitch) method <- "ABEL"
+  if (CVwR > reg$CVswitch) {
+    if (regulator != "FDA") method <- "ABEL"
+    if (regulator == "FDA") method <- "RSABE"
+  }
   limits <- as.numeric(scABEL(CV = CVwR, regulator = reg))
   U <- limits[2] # Simulate at the upper (expanded) limit. For CVwR
   # 30% that's 1.25. Due to the symmetry simulations
-  # at the lower limit (0.80) would work as well.
+  # at the lower limit (0.80) should work as well.
   if (alpha.pre != alpha) {
     al <- alpha.pre # If pre-specified, use alpha.pre.
   } else {
@@ -144,8 +162,8 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
     if (sdsims) cat("Be patient. Simulating subject data will take a good while!\n\n")  
     cat("+++++++++++ scaled (widened) ABEL ++++++++++++\n")
     cat("         iteratively adjusted alpha\n")
-    if (regulator == "EMA") cat("   (simulations based on ANOVA evaluation)\n")
-    if (regulator == "HC") cat("(simulations based on intra-subject contrasts)\n")
+    if (reg$name == "EMA") cat("   (simulations based on ANOVA evaluation)\n")
+    if (reg$name %in% c("HC", "FDA")) cat("(simulations based on intra-subject contrasts)\n")
     cat("----------------------------------------------\n")
     cat("Study design: ")
     cat(paste0(design, " (", type[match(design, designs)], ")\n"))
@@ -159,7 +177,7 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
       txt <- paste0(txt, ", ")
     }
     cat(paste0(txt, "n(i) ", paste0(n, collapse = "|"), " (N ", sum(n),
-                    ")\n"))
+               ")\n"))
     txt <- paste0("Nominal alpha                 : ", signif(alpha, 5))
     if (!is.na(alpha.pre) && (alpha.pre != alpha)) {
       txt <- paste0(txt, ", pre-specified alpha ", alpha.pre, "\n")
@@ -170,30 +188,48 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
     cat("True ratio                    :", sprintf("%.4f", theta0), "\n")
     cat(paste0("Regulatory settings           : ", reg$name, " (",
                method, ")\n"))
-
-        # better theta1, theta2 as BE limits, PE constraint?
+    
+    # better theta1, theta2 as BE limits, PE constraint?
     if (CVwR <= reg$CVswitch) {
       cat("Switching CVwR                : ", reg$CVswitch, "\n",
           "BE limits                     : 0.8000 ... 1.2500\n", sep="")
     } else {
       cat(paste("Switching CVwR                :", reg$CVswitch,
-                "\nRegulatory constant           :", reg$r_const, "\n"))
-      cat(sprintf("%s               : %.4f%s%.4f%s", "Expanded limits",
-                  limits[1], " ... ", limits[2], "\n"))
+                "\nRegulatory constant           :", signif(reg$r_const, 4), "\n"))
+      if (!reg$name == "FDA") { # EMA or HC
+        cat(sprintf("%s               : %.4f%s%.4f%s", "Expanded limits",
+                    limits[1], " ... ", limits[2], "\n"))
+      } else {                  # FDA
+        cat(sprintf("%s             : %.4f%s%.4f%s", "Implied BE limits",
+                    limits[1], " ... ", limits[2], "\n"))
+      }
     }
-    cat("Upper scaling cap             : CVwR >", reg$CVcap, "\n")
+    if (regulator != "FDA")
+      cat("Upper scaling cap             : CVwR >", reg$CVcap, "\n")
     cat("PE constraints                : 0.8000 ... 1.2500\n")
     if (progress) cat("Progress of each iteration:\n")
     if (flushable) flush.console() # advance console output.
   }
   if (!sdsims) { # simulate underlying statistics
-    TIE[1] <- power.scABEL(alpha = al, CV = CV, theta0 = U, n = n,
-                           design = design, regulator = reg,
-                           nsims = nsims, setseed = setseed)
+    if (!reg$name == "FDA") { # EMA or HC
+      TIE[1] <- power.scABEL(alpha = al, CV = CV, theta0 = U, n = n,
+                             design = design, regulator = reg,
+                             nsims = nsims, setseed = setseed)
+    } else {                  # FDA
+      TIE[1] <- power.RSABE(alpha = al, CV = CV, theta0 = U, n = n,
+                            design = design, regulator = reg,
+                            nsims = nsims, setseed = setseed)
+    }
     no <- no + nsims
-    pwr[1] <- power.scABEL(alpha = al, CV = CV, theta0 = theta0,
-                           n = n, design = design, regulator = reg,
-                           setseed = setseed)
+    if (!reg$name == "FDA") { # EMA or HC
+      pwr[1] <- power.scABEL(alpha = al, CV = CV, theta0 = theta0,
+                             n = n, design = design, regulator = reg,
+                             setseed = setseed)
+    } else {                  # FDA
+      pwr[1] <- power.RSABE(alpha = al, CV = CV, theta0 = theta0,
+                            n = n, design = design, regulator = reg,
+                            setseed = setseed)
+    }
     no <- no + 1e5
   } else { # simulate subject data
     TIE[1] <- power.scABEL.sdsims(alpha = al, CV = CV, theta0 = U, n = n,
@@ -214,12 +250,21 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
     }
     alpha.adj <- x$root
     if (!sdsims) { # simulate underlying statistics
-      TIE[2] <- power.scABEL(alpha = alpha.adj, CV = CV, theta0 = U, n = n,
-                             design = design, regulator = reg,
-                             nsims = nsims, setseed = setseed)
-      pwr[2] <- power.scABEL(alpha = alpha.adj, CV = CV, theta0 = theta0,
-                             n = n, design = design, regulator = reg,
-                             setseed = setseed)
+      if (!reg$name == "FDA") { # EMA or HC
+        TIE[2] <- power.scABEL(alpha = alpha.adj, CV = CV, theta0 = U, n = n,
+                               design = design, regulator = reg,
+                               nsims = nsims, setseed = setseed)
+        pwr[2] <- power.scABEL(alpha = alpha.adj, CV = CV, theta0 = theta0,
+                               n = n, design = design, regulator = reg,
+                               setseed = setseed)
+      } else {                  # FDA
+        TIE[2] <- power.RSABE(alpha = alpha.adj, CV = CV, theta0 = U, n = n,
+                              design = design, regulator = reg,
+                              nsims = nsims, setseed = setseed)
+        pwr[2] <- power.RSABE(alpha = alpha.adj, CV = CV, theta0 = theta0,
+                              n = n, design = design, regulator = reg,
+                              setseed = setseed)
+      }
     } else { # simulate subject data
       TIE[2] <- power.scABEL.sdsims(alpha = alpha.adj, CV = CV, theta0 = U,
                                     n = n, design = design, regulator = reg,
@@ -246,41 +291,41 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
     if (!is.na(pwr[1])) {
       pwr.unadj <- pwr[1]
       txt <- paste0(txt, "\nPower for theta0 ", sprintf("%.4f", theta0),
-                         "       : ", sprintf("%.3f", pwr.unadj))
+                    "       : ", sprintf("%.3f", pwr.unadj))
     }
     if (TIE[1] > alpha) {
       txt <- paste0(txt, "\nIteratively adjusted alpha    : ",
                     sprintf("%.5f", alpha.adj),
                     "\nEmpiric TIE for adjusted alpha: ",
                     sprintf("%.5f", TIE[2]))
-    if (!is.na(pwr[2])) {
-      pwr.adj <- pwr[2]
-      txt <- paste0(txt, "\nPower for theta0 ",sprintf("%.4f", theta0),
-                         "       : ", sprintf("%.3f", pwr.adj))
-      if (details) {
-        txt <- paste0(txt, " (rel. impact: ", sprintf("%+1.3g%%",
-                      100*(pwr[2] - pwr[1])/pwr[1]), ")")
+      if (!is.na(pwr[2])) {
+        pwr.adj <- pwr[2]
+        txt <- paste0(txt, "\nPower for theta0 ",sprintf("%.4f", theta0),
+                      "       : ", sprintf("%.3f", pwr.adj))
+        if (details) {
+          txt <- paste0(txt, " (rel. impact: ", sprintf("%+1.3g%%",
+                                                        100*(pwr[2] - pwr[1])/pwr[1]), ")")
+        }
+        txt <- paste(txt, "\n\n")
+      } else {
+        txt <- paste0(txt, "\n\n")
       }
-      txt <- paste(txt, "\n\n")
-    } else {
-      txt <- paste0(txt, "\n\n")
-    }
       if (details) {
         txt <- paste0(txt, "Runtime    : ", signif(run.time[3], 3),
                       " seconds\nSimulations: ",
                       formatC(no, format = "d", big.mark = ",",
-                        decimal.mark = "."), " (",
+                              decimal.mark = "."), " (",
                       (no - no %% nsims - nsims) / nsims,
                       " iterations)\n\n")
       }
     } else {
       txt <- paste0(txt, "\nTIE not > nominal alpha; ")
       ifelse(alpha.pre == alpha,
-        txt <- paste0(txt, "no adjustment of alpha is required.\n\n"),
-        txt <- paste0(txt, "the chosen pre-specified alpha is ",
-                      "justified.\n\n"))
+             txt <- paste0(txt, "no adjustment of alpha is required.\n\n"),
+             txt <- paste0(txt, "the chosen pre-specified alpha is ",
+                           "justified.\n\n"))
     }
-  cat(txt)
+    cat(txt)
   } else { # print=FALSE
     # Prepare and return list of results.
     res <- list(regulator = reg$name, method = method, design = design,
@@ -299,91 +344,3 @@ scABEL.ad <-function(alpha = 0.05, theta0, theta1, theta2, CV,
     return(res)
   }
 }
-# Examples
-# 1. using all defaults
-#   scABEL.ad(CV=0.3)
-# should return:
-#   +++++++++++ scaled (widened) ABEL ++++++++++++
-#            iteratively adjusted alpha
-#      (simulations based on ANOVA evaluation)
-#   ----------------------------------------------
-#   Study design: 2x3x3 (TRR|RTR|RRT)
-#   log-transformed data (multiplicative model)
-#   1,000,000 studies in each iteration simulated.
-#
-#   CVwR 0.3, n(i) 18|18|18 (N 54)
-#   Nominal alpha                 : 0.05
-#   True ratio                    : 0.900
-#   Regulatory settings           : EMA (ABE)
-#   Switching CVwR                : 0.3
-#   BE limits                     : 0.8000 ... 1.2500
-#   Upper scaling cap             : CVwR > 0.5 
-#   PE constraints                : 0.8000 ... 1.2500
-#   Empiric TIE for alpha 0.0500  : 0.07189
-#   Iteratively adjusted alpha    : 0.03389
-#   Empiric TIE for adjusted alpha: 0.05000
-#   Power for theta0 0.900        : 0.764
-#
-# 2. Explore the impact on power.
-#   scABEL.ad(CV=0.3, design="2x2x4", regulator="EMA", n=34, details=TRUE)
-# should return:
-#   +++++++++++ scaled (widened) ABEL +++++++++++
-#            iteratively adjusted alpha
-#      (simulations based on ANOVA evaluation)
-#   ----------------------------------------------
-#   Study design: 2x2x4 (TRTR|RTRT)
-#   log-transformed data (multiplicative model)
-#   1,000,000 studies in each iteration simulated.
-#
-#   CVwR 0.3, n(i) 17|17 (N 34)
-#   Nominal alpha                 : 0.05
-#   True ratio                    : 0.900
-#   Regulatory settings           : EMA (ABE)
-#   Switching CVwR                : 0.3
-#   BE limits                     : 0.8000 ... 1.2500
-#   Upper scaling cap             : CVwR > 0.5 
-#   PE constraints                : 0.8000 ... 1.2500
-#   Empiric TIE for alpha 0.0500  : 0.08163 (rel. change of risk: +63.3%)
-#   Power for theta0 0.900        : 0.803
-#   Iteratively adjusted alpha    : 0.02857
-#   Empiric TIE for adjusted alpha: 0.05000
-#   Power for theta0 0.900        : 0.725 (rel. impact: -9.68%)
-#
-#   Runtime    : 5.18 seconds
-#   Simulations: 5,100,000 (4 iterations)
-#
-# 3. Explore whether a pre-specified alpha maintains the consumer's risk;
-#    Health Canada, different CVs of T and R and slight unbalance in the data expected.
-#   scABEL.ad(CV=CVp2CV(0.3, ratio=0.75), design="2x2x4", regulator="HC", n=c(15, 14), alpha.pre=0.025)
-# should return:
-#   +++++++++++ scaled (widened) ABEL ++++++++++++
-#            iteratively adjusted alpha
-#   (simulations based on intra-subject contrasts)
-#   ----------------------------------------------
-#   Study design: 2x2x4 (TRTR|RTRT)
-#   log-transformed data (multiplicative model)
-#   1,000,000 studies in each iteration simulated.
-#
-#   CVwR 0.3217, CVwT 0.2769, n(i) 15|14 (N 29)
-#   Nominal alpha                 : 0.05, pre-specified alpha 0.025
-#   True ratio                    : 0.900
-#   Regulatory settings           : HC (ABEL)
-#   Switching CVwR                : 0.3 
-#   Regulatory constant           : 0.76 
-#   Expanded limits               : 0.7878 ... 1.2694
-#   Upper scaling cap             : CVwR > 0.57382 
-#   PE constraints                : 0.8000 ... 1.2500
-#   Empiric TIE for alpha 0.0250  : 0.04373
-#   Power for theta0 0.9000       : 0.670
-#   TIE not > nominal alpha; the chosen pre-specified alpha is justified.
-#
-# 4. Assign to a variable and subsequently call the results
-#   x <- scABEL.ad(CV=0.3, design="2x2x4", regulator="EMA", n=34, print=FALSE, alpha.pre=0.025)
-# TIE for the requested alpha
-#   x$alpha.adj
-#   [1] NA       # No adjustment was performed.
-#   x$TIE.unadj
-#   [1] 0.044427 # No inflation of the TIE; 0.025 is justified.
-#   x$pwr.unadj
-#   [1] 0.70537  # Consider to increase the sample size!
-#   print(as.data.frame(x), row.names = FALSE) # The entire list of results.
